<?php

declare(strict_types=1);

namespace FiloBlu\Refilo\Block\Adminhtml\Form\Field;

use FiloBlu\Configuration\Module\Block\Adminhtml\Form\Field\BooleanColumn;
use FiloBlu\Configuration\Module\Block\Adminhtml\Form\Field\TextColumn;
use Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray;

/**
 *
 */
class CspRules extends AbstractFieldArray
{

    protected $_addAfter = false;

    protected $_template = 'FiloBlu_Configuration::system/config/form/field/array.phtml';

    /**
     * Obtain existing data from form element
     *
     * Each row will be instance of \Magento\Framework\DataObject
     *
     * @return array
     */
    public function getArrayRows()
    {
        $element = $this->getElement();

        if (!$element->getValue() || !is_array($element->getValue())) {
            $element->setValue([
                uniqid('_') => ['rule' => 'google-analytics', 'enabled' => false],
                uniqid('_') => ['rule' => 'google-tag-manager', 'enabled' => false],
                uniqid('_') => ['rule' => 'google-recaptcha', 'enabled' => false],
                uniqid('_') => ['rule' => 'zendesk', 'enabled' => false],
                uniqid('_') => ['rule' => 'polyfill', 'enabled' => false],
                uniqid('_') => ['rule' => 'filoblu', 'enabled' => false],
            ]);
        }

        return parent::getArrayRows();
    }

    /**
     * Prepare rendering the new field by adding all the needed columns
     */
    protected function _prepareToRender()
    {
        $this->addColumn(
            'rule',
            [
                'label'    => __('Application'),
                'renderer' => $this->getLayout()->createBlock(TextColumn::class)
            ]
        );
        $this->addColumn(
            'enabled',
            [
                'enabled'  => __('Enabled'),
                'renderer' => $this->getLayout()->createBlock(
                    BooleanColumn::class
                )
            ]
        );
    }
}
